@@ -14,7 +14,6 @@ deleteUserRoles <- function(rcon,
 
 deleteUserRoles.redcapApiConnection <- function(rcon, 
                                                 user_roles,
-                                                refresh = TRUE,
                                                 ...,
                                                 error_handling = getOption("redcap_error_handling"), 
                                                 config = list(), 
@@ -33,11 +32,6 @@ deleteUserRoles.redcapApiConnection <- function(rcon,
                               any.missing = FALSE, 
                               add = coll)
   
-  checkmate::assert_logical(x = refresh, 
-                            len = 1, 
-                            null.ok = FALSE, 
-                            add = coll)
-  
   error_handling <- checkmate::matchArg(x = error_handling, 
                                         choices = c("null", "error"),
                                         .var.name = "error_handling",
@@ -77,14 +71,12 @@ deleteUserRoles.redcapApiConnection <- function(rcon,
                           body = c(body, api_param), 
                           config = config)
   
+  rcon$flush_user_roles()
+  
   if (response$status_code != 200){
     redcapError(response, 
                  error_handling = error_handling)
   }
   
-  if (refresh){
-    rcon$refresh_user_roles()
-  }
-  
   invisible(as.character(response))
 }
