@@ -14,8 +14,6 @@
 #' @param override `logical(1)`. By default, data will add to or modify 
 #'   existing arms data. When `TRUE`, all the existing arms data is 
 #'   deleted and replaced with the contents of `data`.
-#' @param refresh `logical(1)` If `TRUE`, the cached arms data will
-#'   be refreshed after the API action is complete.
 #' @param arms `character` or `integerish` identifying the arm 
 #'   numbers to export or delete.
 #' 
@@ -98,8 +96,7 @@
 armsMethods <- function(rcon, 
                         arms, 
                         data, 
-                        override, 
-                        refresh, 
+                        override,  
                         ..., 
                         error_handling, 
                         config, 
