@@ -16,8 +16,6 @@
 #'   not.  Form names should match those in the second column of the data 
 #'   dictionary, and not the display names shown on the web interface.
 #' @param data `data.frame` with the Meta Data to import. 
-#' @param refresh `logical(1)`. When `TRUE`, the cached metadata
-#'   and instruments will be refreshed after the import.
 #' @param field_types `character` giving the acceptable field types
 #'   when validating the `field_type` column. This  
 #' @param validation_types `character` giving the acceptable values 
@@ -119,8 +117,7 @@
 metaDataMethodsArgs <- function(rcon, 
                                 fields, 
                                 forms, 
-                                data, 
-                                refresh,
+                                data,
                                 ...,
                                 field_types, 
                                 validation_types, 
