@@ -6,8 +6,21 @@
 #'   be the first field in the meta data. The second, if provided, will
 #'   be the name of the secondary unique field specified in the project.
 #'
-#' @param rcon A \code{redcapConnection} object. 
+#' @inheritParams common-rcon-arg
 #' 
+#' @return 
+#' Returns a character vector with the field names that uniquely identify
+#' an experimental unit.
+#' 
+#' @examples
+#' \dontrun{
+#' unlockREDCap(connections = c(rcon = "project_alias"), 
+#'              url = "your_redcap_url", 
+#'              keyring = "API_KEYs", 
+#'              envir = globalenv())
+#'              
+#' getProjectIdFields(rcon)
+#' }
 
 getProjectIdFields <- function(rcon){
   coll <- checkmate::makeAssertCollection()
@@ -26,9 +39,16 @@ getProjectIdFields <- function(rcon){
     isTRUE(!is.na(secondary_unique_field)) &&
     isTRUE(!trimws(secondary_unique_field) %in% "")
   
+  if(has_secondary_field &&
+     isFALSE(secondary_unique_field %in% rcon$metadata()$field_name))
+  {
+    has_secondary_field <- FALSE
+    warning("Project information specifies a secondary unique field that does not exist.")
+  }
+  
   if (has_secondary_field){
     c(primary_unique_field, secondary_unique_field)
   } else {
     primary_unique_field
   }
-}
\ No newline at end of file
+}
